package com.ruoyi.business.service;

import java.util.List;
import com.ruoyi.business.domain.HwScene;
import com.ruoyi.business.domain.VO.HwSceneVo;

/**
 * 场景信息Service接口
 *
 * @author xins
 * @date 2023-08-23
 */
public interface IHwSceneService
{
    /**
     * 查询场景信息
     *
     * @param sceneId 场景信息主键
     * @return 场景信息
     */
    public HwScene selectHwSceneBySceneId(Long sceneId);


    public List<HwScene> selectHwSceneBySceneModeId(Long sceneModeId);

    /**
     * 查询场景信息列表
     *
     * @param hwScene 场景信息
     * @return 场景信息集合
     */
    public List<HwScene> selectHwSceneList(HwScene hwScene);
    public List<HwSceneVo> selectHwSceneList2(HwSceneVo hwScene);


    /**
     * 新增场景信息
     *
     * @param hwScene 场景信息
     * @return 结果
     */
    public int insertHwScene(HwScene hwScene);

    /**
     * 修改场景信息
     *
     * @param hwScene 场景信息
     * @return 结果
     */
    public int updateHwScene(HwScene hwScene);

    /**
     * 批量删除场景信息
     *
     * @param sceneIds 需要删除的场景信息主键集合
     * @return 结果
     */
    public int deleteHwSceneBySceneIds(Long[] sceneIds);

    /**
     * 删除场景信息信息
     *
     * @param sceneId 场景信息主键
     * @return 结果
     */
    public int deleteHwSceneBySceneId(Long sceneId);
}
